/**
 * The HawAPI options configuration.
 */
declare class HawAPIOptions {
    /**
     * The endpoint of the HawAPI instance
     *
     * @default 'https://hawapi.theproject.id/api'
     */
    endpoint: string;
    /**
     * The version of the API
     *
     * @default 'v1'
     */
    version: string;
    /**
     * The language of items in request
     *
     * **Note: This value can be overwritten later**
     *
     * @default 'en-US'
     */
    language: string;
    /**
     * The timeout of a response in milliseconds
     *
     * @default 10 * 1000 // (10 seconds)
     */
    timeout: number;
    /**
     * The HawAPI token (JWT) \
     * By default, all requests are made with **'ANONYMOUS'** tier with limit of **8 req/60s**
     *
     * See more {@link https://hawapi.theproject.id/docs/guides/rate-limiting}
     */
    token?: string;
    /**
     * Define if the package should save (in-memory) all request results
     *
     * @default true
     */
    inMemoryCache: boolean;
    constructor(config?: Partial<HawAPIOptions>);
}
export default HawAPIOptions;
