import HawAPIOptions from './HawAPIOptions';
import { EndpointType } from './enums';
import { Filters, Pageable } from './filters';
import { RequestResult } from './models';
/**
 * Method to validate target
 * @param target The target name
 * @returns true if is a valid target or throw a error
 */
export declare function isValidTargetOrThrow(target: EndpointType): boolean;
/**
 * Method to build the client response
 * @param body The body response from API request
 * @param headers The response header
 * @param status The response status code
 * @returns An new {@link RequestResult} with all required information
 * @throws An error if page index ({@link API_HEADER_PAGE_INDEX}) is less then 0
 */
export declare function buildResult<T>(body: T, headers: Headers, status: number): RequestResult<T>;
/**
 * Method to handle the next/prev page index
 * @param page The current page index
 * @param increase Determine if page index will be increase or decrease
 * @returns Updated page index
 * @throws An error if page index ({@link API_HEADER_PAGE_INDEX}) is less than 0
 */
export declare function handlePagination(page: number, increase: boolean): number | null;
/**
 * Method to create the url using API:
 * - Url
 * - Version
 * - Target
 * - Params
 *   - Filters
 *   - Pageable
 *
 * @param target
 * @param filters
 * @param pageable
 * @returns A complete url path with all params and filters
 */
export declare function buildUrl(target: string, options: HawAPIOptions, filters?: Filters | null, pageable?: Pageable | null): string;
