import { RequestResult } from '../models';
/**
 * In memory cache manager
 */
export declare class InMemoryCacheManager {
    private storage;
    private useCache;
    constructor(useCache: boolean);
    /**
     * Method to get all keys of cached data
     * @returns All cached keys
     */
    keys(): Promise<IterableIterator<string>>;
    /**
     * Method to clear all cached data
     * @returns The count of all cleaned data
     */
    clear(): Promise<number>;
    /**
     * Method to create/set a new cache data
     *
     * **Note: If {@link useCache} is false, no data will be cached** \
     * **Note: If an element with the same key already exists, the element will be updated.**
     *
     * @param key The cache key
     * @param value The value to be cached
     */
    set(key: string, value: RequestResult<unknown>): Promise<void>;
    /**
     * Method to get specific data from key
     * @param key The cache key
     * @returns The {@link RequestResult} value, or undefined if no data is found
     */
    get<T>(key: string): Promise<RequestResult<T> | undefined>;
    /**
     * Method to remove specific cache data
     * @param key The cache key
     * @returns true if an element in the Map existed and has been removed, or false if the element does not exist.
     */
    remove(key: string): Promise<boolean>;
    /**
     * Method to remove a list of cache data
     * @param keys The cache keys
     * @returns The count of all removed data
     */
    removeAllIn(keys: string[]): Promise<number>;
    /**
     * Method to get the size of cached data
     * @returns The count of all cached data
     */
    size(): Promise<number>;
}
